import argparse
import orgutils
#from src.orgutils.orgutils import orgutils



def main():
    
    parser = argparse.ArgumentParser('Takes in parameters for skelorg to run')
    parser.add_argument('command',default='translate')
    parser.add_argument('--translator')
    parser.add_argument('--translatee')
    with open(args.translatee) as f:
        org_str_content = str(f.read())
    with open(args.translator) as f:
        org_str_translator = str(f.read())
    #print(dictToHtml(orgutils.orgToDict(filename='test.org'), full_document=True))
    translator = OrgNode(key='html_translate', content=org_str_translator)
    translatee = OrgNode(key=args.org_file, content=org_str_content)
    print(translator.translate(org_to_translate=translatee))

    
    
    
        

    
    
    

if __name__ == '__main__':
    main()



from SAPOFTO import SAPOFTO

def applySurvey(survey_sapofto):
    for question_key in survey_sapofto.keys():
        if not survey_sapofto[question_key].hasTag('survey'):
            continue
        question_prompt = survey_sapofto[question_key].getValue()
        survey_sapofto[question_key].setValue(input(question_prompt))
        survey_sapofto.addTag('answered')
        survey_sapofto.removeTag('survey')
    return survey_sapofto
            



# pynwb imports
import pynwb
from pynwb import TimeSeries
from pynwb import NWBHDF5IO
from pynwb import NWBFile
from pynwb.ecephys import ElectricalSeries
from orgutils import orgutils

from datetime import datetime
from dateutil.tz import tzlocal
from brainflow.board_shim import BoardShim, BrainFlowInputParams
from brainflow.data_filter import DataFilter, FilterTypes, AggOperations

import brainflow as bf
import pandas as pd
import argparse
import time
import os

import numpy as np

CYTON_BOARD = 0


class NwborgExperiment (object):
    def __init__ (self, experiment_path): # actual argument should be a path to the nwborg experiment folder and that's it
        # read in stuff necessary to make self.nwb_file
        # then (maybe recursively) iterate over the rest of the thing paying attention to tags
        self.overviewOrg = None
        self.hwConfigDict = None
        self.sessionSkeletons = None
        
        # first read in the baseline NWB function
        for filename in os.listdir(experiment_path):
            if filename.endswith('overview.org'):
                # bingo, read in the org as a dictionary
                self.overviewOrg = orgutils.orgToDict(filename=os.path.join(experiment_path, filename))
            else
        self.sessionSkeletons = self.overviewOrg['Session Skeletons']
        

    def createSessionOrgs(self):
        print('TODO implement createsessionorgs')

    def buildNwbFiles():

    def recordSession
        
    


def main():
    argparse


if __name__ == '__main__':
    main()



import argparse
from nwborglab import initHandler
from nwborglab import subjectHandler
from nwborglab import sessionHandler
from nwborglab import scheduleHandler

def main():
    parser = argparse.ArgumentParser('nwborglab','Takes in parameters for nwborg to run')
    
    # add the parameters for the UltracortexNwbTimeSeries contructor as command line arguments
    parser.add_argument('--command', help='command to be run', default='help', nargs='*')
    
    #parser.add_argument('args', nargs=argparse.REMAINDER)
    # parse the args
    # TODO make a .log file all output is appended to then also have a -l or --loud flag for printing output to standard output
    
    args, unknown = parser.parse_known_args()
    #Namespace(args)
    print(unknown)
    # call appropriate command function
    command = args.command[0]
    command_args = args.command[1:]
    
    if command == 'init':
        initHandler.init(command_args)

    if command == 'schedule':
        scheduleHandler.schedule(command_args)
        
    if command == 'assign':
        assignHandler(command_args)

    if command == 'subject':
        subjectHandler.createSubject(command_args)

    if command == 'session':
        if command_args[0] == 'build':
            sessionHandler.generateSessionCode(command_args[1:])
        if command_args[0] == 'schedule':
            sessionHandler.scheduleSession(command_args[1:])
        if command_args[0] == 'start':
            sessionHandler.quickstartSession(command_args[1:])
        if command_args[0] == 'quickstart':
            sessionHandler.quickstartSession(command_args[1:], unknown=unknown)
        if command_args[0] == 'quickstartmarathon':
            session_resultant_metadata = sessionHandler.quickstartSession(command_args[1:])
            while True:
                print('Session complete!\n')
                answer =input("Press 'enter' when you are ready to continue to the next session, or q to quit...")
                if answer == 'q':
                    quit()
                else:                    
                    session_resultant_metadata = sessionHandler.quickstartSession(args=session_resultant_metadata['args'],
                                                                                  session_dict=session_resultant_metadata['session_dict'],
                                                                                  subject_id_dict=session_resultant_metadata['subject_id_dict'])
                    

    print(command)
    print(command_args)
    
if __name__ == '__main__':
    main()
